@@ -287,7 +287,8 @@ bool RPatternPackageFilter::filterOrigin(Pattern pat, RPackage *pkg)
 bool RPatternPackageFilter::filter(RPackage *pkg)
 {
    bool found;
-   bool globalfound = true;
+   bool and_mode = _config->FindB("Synaptic::Filters::andMode", true);
+   bool globalfound = and_mode;
    bool useregexp = _config->FindB("Synaptic::UseRegexp", false);
 
    if (_patterns.size() == 0)
@@ -345,7 +346,10 @@ bool RPatternPackageFilter::filter(RPackage *pkg)
          found = !found;
       }
 
-      globalfound &= found;
+      if(and_mode)
+	 globalfound &= found;
+      else
+	 globalfound |= found;
    }
 
    return globalfound;
