@@ -80,6 +80,10 @@ class RGGladeUserDialog : public RGUserDialog
     RGGladeUserDialog(RGWindow* parent, const char *name);
     virtual ~RGGladeUserDialog()  { gtk_widget_destroy(_dialog); };
 
+    void setTitle(string title) { 
+       gtk_window_set_title(GTK_WINDOW(_dialog),title.c_str());
+    }
+
     int run(const char *name=NULL, bool return_gtk_response=false);
     GladeXML *getGladeXML() { return gladeXML; };
 };
